==> qt-creator-opensource-src-4.4.0.zip: qt-creator-opensource-src-4.4.0/src/plugins/debugger/shared/symbolpathsdialog.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QDialog>
#include <QString>

namespace Debugger {
namespace Internal {

namespace Ui { class SymbolPathsDialog; }

class SymbolPathsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SymbolPathsDialog(QWidget *parent = 0);
    ~SymbolPathsDialog();

    bool useSymbolCache() const;
    bool useSymbolServer() const;
    QString path() const;
    bool doNotAskAgain() const;

    void setUseSymbolCache(bool useSymbolCache);
    void setUseSymbolServer(bool useSymbolServer);
    void setPath(const QString &path);
    void setDoNotAskAgain(bool doNotAskAgain) const;

    static bool useCommonSymbolPaths(bool &useSymbolCache, bool &useSymbolServer, QString &path);

private:
    Ui::SymbolPathsDialog *ui;
};

} // namespace Internal
} // namespace Debugger

==> qt-creator-opensource-src-4.7.0.zip: qt-creator-opensource-src-4.7.0/src/plugins/debugger/shared/symbolpathsdialog.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QDialog>
#include <QString>

namespace Debugger {
namespace Internal {

namespace Ui { class SymbolPathsDialog; }

class SymbolPathsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SymbolPathsDialog(QWidget *parent = nullptr);
    ~SymbolPathsDialog();

    bool useSymbolCache() const;
    bool useSymbolServer() const;
    QString path() const;
    bool doNotAskAgain() const;

    void setUseSymbolCache(bool useSymbolCache);
    void setUseSymbolServer(bool useSymbolServer);
    void setPath(const QString &path);
    void setDoNotAskAgain(bool doNotAskAgain) const;

    static bool useCommonSymbolPaths(bool &useSymbolCache, bool &useSymbolServer, QString &path);

private:
    Ui::SymbolPathsDialog *ui;
};

} // namespace Internal
} // namespace Debugger
